<?php
/**
 * Leda Theme Customizer
 */

// Loads custom control
require trailingslashit( get_template_directory() ) . 'inc/customizer/controls/custom-text.php';

// Loads the customizer settings
require trailingslashit( get_template_directory() ) . 'inc/customizer/posts-slider.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/featured-posts.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/posts.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/social.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/misc.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/layouts.php';
require trailingslashit( get_template_directory() ) . 'inc/customizer/colors.php';

/**
 * Custom customizer functions.
 */
function leda_customize_functions( $wp_customize ) {

	// Register new panel: Design
	$wp_customize->add_panel( 'leda_design', array(
		'title'       => esc_html__( 'Design', 'leda' ),
		'description' => esc_html__( 'This panel is used for customizing the design of your site.', 'leda' ),
		'priority'    => 125,
	) );

	// Register new panel: Theme Options
	$wp_customize->add_panel( 'leda_options', array(
		'title'       => esc_html__( 'Theme Options', 'leda' ),
		'description' => esc_html__( 'This panel is used for customizing the Leda theme.', 'leda' ),
		'priority'    => 130,
	) );

	// Live preview of Site Title
	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage';

	// Enable selective refresh to the Site Title
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'            => '.site-title a',
			'settings'         => array( 'blogname' ),
			'render_callback'  => function() {
				return get_bloginfo( 'name', 'display' );
			}
		) );
	}

	// Move the Colors section.
	$wp_customize->get_section( 'colors' )->panel    = 'leda_design';
	$wp_customize->get_section( 'colors' )->priority = 1;

	// Move the Header Image section.
	$wp_customize->get_section( 'header_image' )->panel    = 'leda_design';
	$wp_customize->get_section( 'header_image' )->priority = 5;

	// Move the Background Image section.
	$wp_customize->get_section( 'background_image' )->panel    = 'leda_design';
	$wp_customize->get_section( 'background_image' )->priority = 7;

	// Move the Static Front Page section.
	$wp_customize->get_section( 'static_front_page' )->panel    = 'leda_design';
	$wp_customize->get_section( 'static_front_page' )->priority = 9;

	// Move the Additional CSS section.
	$wp_customize->get_section( 'custom_css' )->panel    = 'leda_design';
	$wp_customize->get_section( 'custom_css' )->priority = 11;

	// Move background color to background image section.
	$wp_customize->get_section( 'background_image' )->title = esc_html__( 'Background', 'leda' );
	$wp_customize->get_control( 'background_color' )->section = 'background_image';

	// Move header text color to header image section.
	$wp_customize->get_section( 'header_image' )->title = esc_html__( 'Header', 'leda' );
	$wp_customize->get_control( 'header_textcolor' )->section = 'header_image';
	// $wp_customize->get_control( 'header_textcolor' )->priority = 99;

}
add_action( 'customize_register', 'leda_customize_functions', 99 );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function leda_customize_preview_js() {
	wp_enqueue_script( 'leda-customizer', get_template_directory_uri() . '/assets/js/customizer/customizer.js', array( 'customize-preview', 'jquery' ) );
}
add_action( 'customize_preview_init', 'leda_customize_preview_js' );

/**
 * Custom styles.
 */
function leda_custom_css() {

	// Set up empty variable.
	$css = '';

	$text = get_theme_mod( 'leda-global-text-color', '#454545' );
	if ( $text != '#454545' ) {
		$css .= 'body { color: ' . sanitize_hex_color( $text ) . '; } ';
	}

	$link = get_theme_mod( 'leda-global-link-color', '#278db0' );
	if ( $link != '#278db0' ) {
		$css .= 'a, a:visited, a:link { color: ' . sanitize_hex_color( $link ) . '; } ';
	}

	$search_icon = get_theme_mod( 'leda-search-icon-color', '#454545' );
	if ( $search_icon != '#454545' ) {
		$css .= '.search-toggle { color: ' . sanitize_hex_color( $search_icon ) . '; } ';
	}

	$header_bg = get_theme_mod( 'leda-header-bg-color', '#ffffff' );
	if ( $header_bg != '#ffffff' ) {
		$css .= '.site-header { background-color: ' . sanitize_hex_color( $header_bg ) . '; } ';
	}

	$site_title = get_theme_mod( 'leda-site-title-color', '#454545' );
	if ( $site_title != '#454545' ) {
		$css .= '#masthead .site-title a { color: ' . sanitize_hex_color( $site_title ) . '; } ';
	}

	$site_desc = get_theme_mod( 'leda-site-desc-color', '#777777' );
	if ( $site_desc != '#777777' ) {
		$css .= '#masthead .site-description { color: ' . sanitize_hex_color( $site_desc ) . '; } ';
	}

	$footer_bg = get_theme_mod( 'leda-footer-bg-color', '#f5f5f5' );
	if ( $footer_bg != '#f5f5f5' ) {
		$css .= '.site-footer { background-color: ' . sanitize_hex_color( $footer_bg ) . '; } ';
	}

	$footer_text = get_theme_mod( 'leda-footer-text-color', '#454545' );
	if ( $footer_text != '#454545' ) {
		$css .= '.site-footer { color: ' . sanitize_hex_color( $footer_text ) . '; } ';
	}

	$footer_link = get_theme_mod( 'leda-footer-link-color', '#454545' );
	if ( $footer_link != '#454545' ) {
		$css .= '.site-footer p a { color: ' . sanitize_hex_color( $footer_link ) . '; } ';
	}

	$social_bg = get_theme_mod( 'leda-footer-social-bg-color', '#454545' );
	if ( $social_bg != '#454545' ) {
		$css .= '.social-links a { background-color: ' . sanitize_hex_color( $social_bg ) . '; } ';
	}

	$social_bg_hover = get_theme_mod( 'leda-footer-social-bg-hover-color', '#278db0' );
	if ( $social_bg_hover != '#278db0' ) {
		$css .= '.social-links a:hover { background-color: ' . sanitize_hex_color( $social_bg_hover ) . '; } ';
	}

	$social_icon = get_theme_mod( 'leda-footer-social-icon-color', '#ffffff' );
	if ( $social_icon != '#ffffff' ) {
		$css .= '.social-links a { color: ' . sanitize_hex_color( $social_icon ) . '; } ';
	}

	$menu_bg = get_theme_mod( 'leda-menu-link-bg-color', '#ffffff' );
	if ( $menu_bg != '#ffffff' ) {
		$css .= '.main-navigation { background-color: ' . sanitize_hex_color( $menu_bg ) . '; } ';
	}

	$menu_border = get_theme_mod( 'leda-menu-border-color', '#e9e9e9' );
	if ( $menu_border != '#e9e9e9' ) {
		$css .= '.main-navigation { border-color: ' . sanitize_hex_color( $menu_border ) . '; } ';
	}

	$menu_link = get_theme_mod( 'leda-menu-link-color', '#278db0' );
	if ( $menu_link != '#278db0' ) {
		$css .= '#site-navigation ul li a { color: ' . sanitize_hex_color( $menu_link ) . '; } ';
	}

	$menu_hover = get_theme_mod( 'leda-menu-current-hover-color', '#454545' );
	if ( $menu_hover != '#454545' ) {
		$css .= '.menu-primary-items li a:hover, .menu-primary-items li.current-menu-item > a, .menu-primary-items li .sub-menu a:hover, .menu-primary-items li.menu-item-has-children:hover::after { color: ' . sanitize_hex_color( $menu_hover ) . '; } ';
	}

	$post_text = get_theme_mod( 'leda-post-text-color', '#454545' );
	if ( $post_text != '#454545' ) {
		$css .= '.single .entry-content { color: ' . sanitize_hex_color( $post_text ) . '; } ';
	}

	$post_heading = get_theme_mod( 'leda-post-heading-color', '#454545' );
	if ( $post_heading != '#454545' ) {
		$css .= '.single .entry-title, .single .entry-content h1, .single .entry-content h2, .single .entry-content h3,.single .entry-content h4, .single .entry-content h5, .single .entry-content h6 { color: ' . sanitize_hex_color( $post_heading ) . '; } ';
	}

	$post_link = get_theme_mod( 'leda-post-link-color', '#278db0' );
	if ( $post_link != '#278db0' ) {
		$css .= '.single .entry-content a, .cat-links a { color: ' . sanitize_hex_color( $post_link ) . '; } ';
	}

	$post_link_hover = get_theme_mod( 'leda-post-link-hover-color', '#37abd3' );
	if ( $post_link_hover != '#37abd3' ) {
		$css .= '.single .entry-content a:hover, .cat-links a:hover { color: ' . sanitize_hex_color( $post_link_hover ) . '; } ';
	}

	$page_text = get_theme_mod( 'leda-page-text-color', '#454545' );
	if ( $page_text != '#454545' ) {
		$css .= '.page .entry-content { color: ' . sanitize_hex_color( $page_text ) . '; } ';
	}

	$page_heading = get_theme_mod( 'leda-page-heading-color', '#454545' );
	if ( $page_heading != '#454545' ) {
		$css .= '.page .entry-title, .page .entry-content h1, .page .entry-content h2, .page .entry-content h3,.page .entry-content h4, .page .entry-content h5, .page .entry-content h6 { color: ' . sanitize_hex_color( $page_heading ) . '; } ';
	}

	$page_link = get_theme_mod( 'leda-page-link-color', '#278db0' );
	if ( $page_link != '#278db0' ) {
		$css .= '.page .entry-content a, .cat-links a { color: ' . sanitize_hex_color( $page_link ) . '; } ';
	}

	$page_link_hover = get_theme_mod( 'leda-page-link-hover-color', '#37abd3' );
	if ( $page_link_hover != '#37abd3' ) {
		$css .= '.page .entry-content a:hover, .cat-links a:hover { color: ' . sanitize_hex_color( $page_link_hover ) . '; } ';
	}

	$widget_title_bg = get_theme_mod( 'leda-widget-bg-title-color', '#ffffff' );
	if ( $widget_title_bg != '#ffffff' ) {
		$css .= '.widget-title { background-color: ' . sanitize_hex_color( $widget_title_bg ) . '; } ';
	}

	$widget_title = get_theme_mod( 'leda-widget-title-color', '#454545' );
	if ( $widget_title != '#454545' ) {
		$css .= '.widget-title { color: ' . sanitize_hex_color( $widget_title ) . '; } ';
	}

	$widget_text = get_theme_mod( 'leda-widget-text-color', '#454545' );
	if ( $widget_text != '#454545' ) {
		$css .= '.widget { color: ' . sanitize_hex_color( $widget_text ) . '; } ';
	}

	$widget_link = get_theme_mod( 'leda-widget-link-color', '#454545' );
	if ( $widget_link != '#454545' ) {
		$css .= '.widget a, .widget li a { color: ' . sanitize_hex_color( $widget_link ) . '; } ';
	}

	$widget_link_hover = get_theme_mod( 'leda-widget-link-hover-color', '#278db0' );
	if ( $widget_link_hover != '#278db0' ) {
		$css .= '.widget a:hover, .widget li a:hover { color: ' . sanitize_hex_color( $widget_link_hover ) . '; } ';
	}

	$widget_border = get_theme_mod( 'leda-widget-border-color', '#e9e9e9' );
	if ( $widget_border != '#e9e9e9' ) {
		$css .= '.widget li { border-color: ' . sanitize_hex_color( $widget_border ) . '; } ';
	}

	// Print the custom style
	wp_add_inline_style( 'leda-style', $css );

}
add_action( 'wp_enqueue_scripts', 'leda_custom_css' );

/**
 * Display theme documentation on customizer page.
 */
function leda_documentation_link() {

	// Enqueue the script
	wp_enqueue_script( 'leda-doc', get_template_directory_uri() . '/assets/js/customizer/doc.js', array(), '1.0.0', true );

	// Localize the script
	wp_localize_script( 'leda-doc', 'prefixL10n',
		array(
			'prefixURL'   => esc_url( 'http://docs.theme-junkie.com/leda/' ),
			'prefixLabel' => esc_html__( 'Documentation', 'leda' ),
		)
	);

}
// add_action( 'customize_controls_enqueue_scripts', 'leda_documentation_link' );

/**
 * Custom RSS feed url.
 */
function leda_custom_rss_url( $output, $feed ) {

	// Get the custom rss feed url
	$url = get_theme_mod( 'leda-custom-rss' );

	// Do not redirect comments feed
	if ( strpos( $output, 'comments' ) ) {
		return $output;
	}

	// Check the settings.
	if ( ! empty( $url ) ) {
		$output = esc_url( $url );
	}

	return $output;
}
add_filter( 'feed_link', 'leda_custom_rss_url', 10, 2 );

/**
 * Retrieve tags list.
 */
function leda_tags_list() {

	// Set up empty array.
	$tags = array();

	// Retrieve available tags.
	$tags_obj = get_tags();

	// Set default/empty tag.
	$tags[''] = esc_html__( 'Select a tag &hellip;', 'leda' );

	// Display the tags.
	foreach ( $tags_obj as $tag ) {
		$tags[$tag->term_id] = esc_attr( $tag->name );
	}

	return $tags;

}

/**
 * Sanitize the checkbox.
 *
 * @param boolean $input.
 * @return boolean (true|false).
 */
function leda_sanitize_checkbox( $input ) {
	if ( 1 == $input ) {
		return true;
	} else {
		return false;
	}
}

/**
 * Sanitize the Footer Credits
 */
function leda_sanitize_textarea( $text ) {
	if ( current_user_can( 'unfiltered_html' ) ) {
		$text = $text;
	} else {
		$text = wp_kses_post( $text );
	}
	return $text;
}

/**
 * Sanitize the post date style value.
 */
function leda_sanitize_post_date_style( $style ) {
	if ( ! in_array( $style, array( 'absolute', 'relative' ) ) ) {
		$style = 'absolute';
	}
	return $style;
}

/**
 * Sanitize home page layout value.
 */
function leda_sanitize_home_layout( $layout ) {
	if ( ! in_array( $layout, array( 'standard', 'grid' ) ) ) {
		$layout = 'standard';
	}
	return $layout;
}
