<?php
/**
 * Custom template tags for this theme.
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package    Leda
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

if ( ! function_exists( 'leda_site_branding' ) ) :
/**
 * Site branding for the site.
 *
 * Display site title by default, but user can change it with their custom logo.
 * They can upload it on Customizer page.
 *
 * @since  1.0.0
 */
function leda_site_branding() {

	// Get the customizer value.
	$logo_id  = get_theme_mod( 'custom_logo' );
	$logo_url = wp_get_attachment_image_src( $logo_id , 'full' );

	// Check if logo available, then display it.
	if ( $logo_id ) :
		echo '<div id="logo" itemscope itemtype="http://schema.org/Brand">' . "\n";
			echo '<a href="' . esc_url( get_home_url() ) . '" itemprop="url" rel="home">' . "\n";
				echo '<img itemprop="logo" src="' . esc_url( $logo_url[0] ) . '" alt="' . esc_attr( get_bloginfo( 'name' ) ) . '" />' . "\n";
			echo '</a>' . "\n";
		echo '</div>' . "\n";

	// If not, then display the Site Title and Site Description.
	elseif ( display_header_text() ) :
		echo '<div id="logo">'. "\n";
			echo '<h1 class="site-title" ' . hybrid_get_attr( 'site-title' ) . '><a href="' . esc_url( get_home_url() ) . '" itemprop="url" rel="home"><span itemprop="headline">' . esc_attr( get_bloginfo( 'name' ) ) . '</span></a></h1>'. "\n";
			echo '<h2 class="site-description" ' . hybrid_get_attr( 'site-description' ) . '>' . esc_attr( get_bloginfo( 'description' ) ) . '</h2>';
		echo '</div>'. "\n";
	endif;

}
endif;

if ( ! function_exists( 'leda_posts_slider' ) ) :
/**
 * Posts slider
 *
 * @since  1.0.0
 */
function leda_posts_slider() {

	// Get the data set in customizer
	$onoff = get_theme_mod( 'leda-slider-enable', 1 );
	$tag   = get_theme_mod( 'leda-slider-tag' );
	$num   = get_theme_mod( 'leda-slider-num', 5 );

	// Display on home page only
	if ( ! is_home() ) {
		return;
	}

	// Disable the posts slider by user selected in the customizer
	if ( $onoff == 0 ) {
		return;
	}

	// Posts query arguments.
	$args = array(
		'posts_per_page' => (int) $num,
		'post_type'      => 'post',
	);

	// Include the tag
	if ( $tag ) {
		$args['tag_id'] = absint( $tag );
	}

	// Allow dev to filter the query.
	$args = apply_filters( 'leda_posts_slider_args', $args );

	// The post query
	$slider = new WP_Query( $args );

	if ( $slider->have_posts() ) : ?>

		<div id="posts-slider" class="owl-carousel owl-theme">
			<?php while ( $slider->have_posts() ) : $slider->the_post(); ?>
				<div class="item">
					<?php if ( has_post_thumbnail() ) : ?>
						<?php the_post_thumbnail( 'leda-slider', array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?>
					<?php endif; ?>
					<div class="slider-content">

						<header class="entry-header">

							<?php if ( 'post' == get_post_type() ) : ?>
								<?php
									/* translators: used between list items, there is a space after the comma */
									$categories_list = get_the_category_list( __( ', ', 'leda' ) );
									if ( $categories_list && leda_categorized_blog() ) :
								?>
								<span class="cat-links" <?php hybrid_attr( 'entry-terms', 'category' ); ?>>
									<?php echo $categories_list; ?>
								</span>
								<i class="fa fa-circle"></i>
								<?php endif; // End if categories ?>
							<?php endif; ?>

							<time class="entry-date published entry-side" datetime="<?php echo esc_attr( get_the_date( 'c' ) ); ?>" <?php hybrid_attr( 'entry-published' ); ?>><?php echo esc_html( get_the_date() ); ?></time>

							<?php the_title( sprintf( '<h2 class="entry-title" ' . hybrid_get_attr( 'entry-title' ) . '><a href="%s" rel="bookmark" itemprop="url">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>

						</header>

						<span class="more-link-wrapper">
							<a href="<?php the_permalink(); ?>" class="more-link"><?php _e( 'Read More', 'leda' ); ?></a>
						</span>

					</div>
				</div>
			<?php endwhile; ?>
		</div>

	<?php endif;

	// Restore original Post Data.
	wp_reset_postdata();

}
endif;

if ( ! function_exists( 'leda_featured_slider' ) ) :
/**
 * Featured posts
 *
 * @since  1.0.0
 */
function leda_featured_slider() {

	// Get the data set in customizer
	$onoff = get_theme_mod( 'leda-featured-enable', 1 );
	$tag   = get_theme_mod( 'leda-featured-tag' );
	$home  = get_theme_mod( 'leda-featured-home-only', 1 );
	$title = get_theme_mod( 'leda-featured-title', esc_html__( 'Featured posts', 'leda' ) );

	// Disable the posts slider by user selected in the customizer
	if ( $onoff == 0 ) {
		return;
	}

	// Display on home page only
	if ( $home == 1 ) {
		if ( ! is_home() ) {
			return;
		}
	}

	// Posts query arguments.
	$args = array(
		'posts_per_page' => 3,
		'post_type'      => 'post',
	);

	// Include the tag
	if ( $tag ) {
		$args['tag_id'] = absint( $tag );
	}

	// Allow dev to filter the query.
	$args = apply_filters( 'leda_featured_posts_args', $args );

	// The post query
	$featured = new WP_Query( $args );

	if ( $featured->have_posts() ) : ?>

		<div class="featured-posts">
			<h3 class="title"><?php echo strip_tags( $title ); ?></h3>
			<?php while ( $featured->have_posts() ) : $featured->the_post(); ?>
				<div class="featured-item">
					<?php if ( has_post_thumbnail() ) : ?>
						<a class="thumbnail-link" href="<?php the_permalink(); ?>"><?php the_post_thumbnail( 'medium', array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?></a>
					<?php endif; ?>
					<?php the_title( sprintf( '<h2 class="entry-title" ' . hybrid_get_attr( 'entry-title' ) . '><a href="%s" rel="bookmark" itemprop="url">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>
					<time class="entry-date published entry-side" datetime="<?php echo esc_attr( get_the_date( 'c' ) ); ?>" <?php hybrid_attr( 'entry-published' ); ?>><?php echo esc_html( get_the_date() ); ?></time>
				</div>
			<?php endwhile; ?>
		</div>

	<?php endif;

	// Restore original Post Data.
	wp_reset_postdata();

}
endif;

if ( ! function_exists( 'leda_main_container' ) ) :
/**
 * Main container class
 *
 * @since  1.0.0
 */
function leda_main_container() {

	// Set up empty variable
	$class = '';

	// Display the class
	if ( is_page() ) {
		$class = 'container';
	} else {
		$class = 'wide-container';
	}

	return apply_filters( 'leda_main_container', $class );

}
endif;

if ( ! function_exists( 'leda_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 *
 * @since 1.0.0
 */
function leda_attachment_meta() {

	?>

	<time class="entry-date published entry-side" datetime="<?php echo esc_attr( get_the_date( 'c' ) ); ?>" <?php hybrid_attr( 'entry-published' ); ?>><?php printf( __( 'Published: %s', 'leda' ), '<span>' . esc_html( get_the_date() ) . '</span>' ); ?></time>

	<span class="entry-author author vcard entry-side" <?php hybrid_attr( 'entry-author' ) ?>>
		<?php printf( __( 'Author: %s', 'leda' ), '<a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '" itemprop="url"><span itemprop="name">' . esc_html( get_the_author() ) . '</span></a>' ); ?>
	</span>

	<?php if ( is_attachment() && wp_attachment_is_image() ) : ?>

		<?php
		$metadata = wp_get_attachment_metadata(); // Retrieve attachment metadata.
		$camera   = $metadata['image_meta']['camera'];
		$aperture = $metadata['image_meta']['aperture'];
		$focal    = $metadata['image_meta']['focal_length'];
		$iso      = $metadata['image_meta']['iso'];
		$shutter  = $metadata['image_meta']['shutter_speed'];
		?>

		<span class="full-size-link entry-side">
			<?php printf( __( 'Size: %s', 'leda' ), '<a href="' . esc_url( wp_get_attachment_url() ) . '">' . $metadata['width'] . ' &times; ' . $metadata['height'] . '</a>' ); ?>
		</span>

		<?php if ( $camera ) : ?>
			<span class="camera entry-side">
				<?php printf( __( 'Camera: %s', 'leda' ), '<span>' . $camera . '</span>' ); ?>
			</span>
		<?php endif; ?>

		<?php if ( $aperture ) : ?>
			<span class="apparture entry-side">
				<?php printf( __( 'Aperture: %s', 'leda' ), '<span>' . $aperture . '</span>' ); ?>
			</span>
		<?php endif; ?>

		<?php if ( $focal ) : ?>
			<span class="focal-length entry-side">
				<?php printf( __( 'Focal Length: %s', 'leda' ), '<span>' . $focal . '</span>' ); ?>
			</span>
		<?php endif; ?>

		<?php if ( $iso ) : ?>
			<span class="iso entry-side">
				<?php printf( __( 'ISO: %s', 'leda' ), '<span>' . $iso . '</span>' ); ?>
			</span>
		<?php endif; ?>

		<?php if ( $shutter ) : ?>
			<span class="shutter-speed entry-side">
				<?php printf( __( 'Shutter Speed: %s', 'leda' ), '<span>' . $shutter . '</span>' ); ?>
			</span>
		<?php endif; ?>

	<?php endif; ?>

	<?php
}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @since  1.0.0
 * @return bool
 */
function leda_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'leda_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,

			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'leda_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so leda_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so leda_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in leda_categorized_blog.
 *
 * @since 1.0.0
 */
function leda_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'leda_categories' );
}
add_action( 'edit_category', 'leda_category_transient_flusher' );
add_action( 'save_post',     'leda_category_transient_flusher' );

if ( ! function_exists( 'leda_get_post_format_link_url' ) ) :
/**
 * Forked from hybrid_get_the_post_format_url.
 * Filters 'get_the_post_format_url' to make for a more robust and back-compatible function.  If WP did
 * not find a URL, check the post content for one.  If nothing is found, return the post permalink.
 * Used in Post Format Link
 *
 * @since 1.0.0
 */
function leda_get_post_format_link_url( $url = '', $post = null ) {

	if ( empty( $url ) ) {

		$post = is_null( $post ) ? get_post() : $post;

		/* Catch links that are not wrapped in an '<a>' tag. */
		$content_url = preg_match( '/<a\s[^>]*?href=[\'"](.+?)[\'"]/is', make_clickable( $post->post_content ), $matches );

		$content_url = ! empty( $matches[1] ) ? esc_url_raw( $matches[1] ) : '';

		$url = ! empty( $content_url ) ? $content_url : get_permalink( $post->ID );
	}

	if ( $url ) {
	?>
		<h2 class="entry-title" itemprop="headline">
			<a href="<?php echo esc_url( $url ); ?>" itemprop="url">
				<?php if ( get_the_title() && ( __( '(Untitled)', 'leda' ) != get_the_title() ) ) { ?>
					<?php the_title(); ?>
				<?php } else { ?>
					<?php echo esc_attr( $url ); ?>
				<?php }	?>
			</a>
		</h2>
	<?php
	}

}
endif;

if ( ! function_exists( 'leda_get_format_gallery' ) ) :
/**
 * Get the [gallery] shortcode from the post content and display it on index page. It require
 * gallery ids [gallery ids=1,2,3,4] to display it as thumbnail slideshow. If no ids exist it
 * just display it as standard [gallery] markup.
 *
 * If no [gallery] shortcode found in the post content, get the attached images to the post and
 * display it as slideshow.
 *
 * @since  1.0.0
 * @uses   get_post_gallery() to get the gallery in the post content.
 * @uses   wp_get_attachment_image() to get the HTML image.
 * @uses   get_children() to get the attached images if no [gallery] found in the post content.
 * @return string
 */
function leda_get_format_gallery() {
	global $post;

	// Set up a default, empty $html variable.
	$html = '';

	// Set up default image size.
	$size = 'large';

	// Check the [gallery] shortcode in post content.
	$gallery = get_post_gallery( $post->ID, false );

	// opening wrapper
	$html = '<div class="owl-carousel owl-theme entry-format">';

		// Check if the [gallery] exist.
		if ( $gallery ) {

			// Check if the gallery ids exist.
			if ( isset( $gallery['ids'] ) ) {

				// Get the gallery ids and convert it into array.
				$ids = explode( ',', $gallery['ids'] );

				// Display the gallery in a cool slideshow on index page.
				foreach( $ids as $id ) {
					$html .= '<div class="item">';
					$html .= wp_get_attachment_image( $id, $size, false, array( 'class' => 'entry-thumbnail' ) );
					$html .= '</div>';
				}

			} else {

				// If gallery ids not exist, display the standard gallery markup.
				// avoid this, since it'll look bad
				// $html = get_post_gallery( $post->ID );

				// if gallery based on images attached to post (only [gallery] in post content)
				// note: in the post content, better to use: [gallery size="large"] or [gallery size="full"]
				$srcs = $gallery['src'];

				// Display the gallery in a cool slideshow on index page.
				foreach( $srcs as $src ) {
					$html .= '<div class="item">';
					$html .= '<img src="' . esc_url( $src ) . '" />';
					$html .= '</div>';
				}

			}

		// If no [gallery] in post content, get attached images to the post.
		} else {

			// Set up default arguments.
			$defaults = array(
				'order'          => 'ASC',
				'post_type'      => 'attachment',
				'post_parent'    => $post->ID,
				'post_mime_type' => 'image',
				'numberposts'    => -1
			);

			// Retrieves attachments from the post.
			$attachments = get_children( apply_filters( 'leda_gallery_format_args', $defaults ) );

			// Check if attachments exist.
			if ( $attachments ) {

				// Display the attachment images in a cool slideshow on index page.
				foreach ( $attachments as $attachment ) {
					$html .= '<div class="item">';
					$html .= wp_get_attachment_image( $attachment->ID, $size, false, array( 'class' => 'entry-thumbnail' ) );
					$html .= '</div>';
				}

			} else {

				// if no [gallery] shortcode and has no attachments, bail them out
				return;

			}

		}

	// closing wrapper
	$html .= '</div>';

	// Return the gallery images.
	return $html;

}
endif;

if ( ! function_exists( 'leda_entry_share' ) ) :
/**
 * Social share.
 *
 * @since 1.0.0
 */
function leda_entry_share() {
	global $post;

	// Get the data set in customizer
	$share  = get_theme_mod( 'leda-post-share', 1 );

	if ( $share == 0 ) {
		return;
	}
	?>
		<div class="entry-share clearfix">
			<ul>
				<li class="twitter"><a href="https://twitter.com/intent/tweet?text=<?php echo esc_attr( get_the_title( $post->ID ) ); ?>&amp;url=<?php echo urlencode( get_permalink( $post->ID ) ); ?>" target="_blank"><i class="fa fa-twitter"></i>Twitter</a></li>
				<li class="facebook"><a href="https://www.facebook.com/sharer/sharer.php?u=<?php echo urlencode( get_permalink( $post->ID ) ); ?>" target="_blank"><i class="fa fa-facebook"></i>Facebook</a></li>
				<li class="google-plus"><a href="https://plus.google.com/share?url=<?php echo urlencode( get_permalink( $post->ID ) ); ?>" target="_blank"><i class="fa fa-google-plus"></i>Google+</a></li>
				<li class="linkedin"><a href="https://www.linkedin.com/shareArticle?mini=true&amp;url=<?php echo urlencode( get_permalink( $post->ID ) ); ?>&amp;title=<?php echo esc_attr( get_the_title( $post->ID ) ); ?>" target="_blank"><i class="fa fa-linkedin"></i>LinkedIn</a></li>
				<li class="pinterest"><a href="http://pinterest.com/pin/create/button/?url=<?php echo urlencode( get_permalink( $post->ID ) ); ?>&amp;media=<?php echo urlencode( wp_get_attachment_url( get_post_thumbnail_id( $post->ID ) ) ); ?>" target="_blank"><i class="fa fa-pinterest"></i>Pinterest</a></li>
			</ul>
		</div>
	<?php
}
endif;

if ( ! function_exists( 'leda_post_author' ) ) :
/**
 * Author post informations.
 *
 * @since  1.0.0
 */
function leda_post_author() {

	// Get the data set in customizer
	$enable = get_theme_mod( 'leda-post-author', 1 );

	// Disable if user choose it.
	if ( $enable == 0 ) {
		return;
	}

	// Bail if not on the single post.
	if ( ! is_single() ) {
		return;
	}

	// Bail if user hasn't fill the Biographical Info field.
	if ( ! get_the_author_meta( 'description' ) ) {
		return;
	}
?>

	<div class="author-bio" <?php hybrid_attr( 'entry-author' ) ?>>
		<?php echo get_avatar( is_email( get_the_author_meta( 'user_email' ) ), apply_filters( 'leda_author_bio_avatar_size', 80 ), '', strip_tags( get_the_author() ) ); ?>
		<div class="description">
			<h3 class="author-title name">
				<a class="author-name url fn n" href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>" rel="author" itemprop="url"><span itemprop="name"><?php echo strip_tags( get_the_author() ); ?></span></a>
			</h3>
			<p class="bio" itemprop="description"><?php echo stripslashes( get_the_author_meta( 'description' ) ); ?></p>
			<ul class="author-social">
				<?php if ( get_the_author_meta( 'url' ) ) : ?>
					<li class="website">
						<a href="<?php echo esc_url( get_the_author_meta( 'url' ) ); ?>"><i class="fa fa-home"></i></a>
					</li>
				<?php endif; ?>
				<?php if ( get_the_author_meta( 'twitter' ) ) : ?>
					<li class="twitter">
						<a href="<?php echo esc_url( get_the_author_meta( 'twitter' ) ); ?>"><i class="fa fa-twitter"></i></a>
					</li>
				<?php endif; ?>
				<?php if ( get_the_author_meta( 'facebook' ) ) : ?>
					<li class="facebook">
						<a href="<?php echo esc_url( get_the_author_meta( 'facebook' ) ); ?>"><i class="fa fa-facebook"></i></a>
					</li>
				<?php endif; ?>
				<?php if ( get_the_author_meta( 'gplus' ) ) : ?>
					<li class="gplus">
						<a href="<?php echo esc_url( get_the_author_meta( 'gplus' ) ); ?>"><i class="fa fa-google-plus"></i></a>
					</li>
				<?php endif; ?>
				<?php if ( get_the_author_meta( 'instagram' ) ) : ?>
					<li class="instagram">
						<a href="<?php echo esc_url( get_the_author_meta( 'instagram' ) ); ?>"><i class="fa fa-instagram"></i></a>
					</li>
				<?php endif; ?>
				<?php if ( get_the_author_meta( 'linkedin' ) ) : ?>
					<li class="linkedin">
						<a href="<?php echo esc_url( get_the_author_meta( 'linkedin' ) ); ?>"><i class="fa fa-linkedin"></i></a>
					</li>
				<?php endif; ?>
			</ul>
		</div>
	</div><!-- .author-bio -->

<?php
}
endif;

if ( ! function_exists( 'leda_related_posts' ) ) :
/**
 * Related posts.
 *
 * @since  1.0.0
 */
function leda_related_posts() {
	global $post;

	// Get the data set in customizer
	$enable  = get_theme_mod( 'leda-related-posts', 1 );
	$img     = get_theme_mod( 'leda-related-posts-img', 1 );

	// Disable if user choose it.
	if ( $enable == 0 ) {
		return;
	}

	// Get the taxonomy terms of the current page for the specified taxonomy.
	$terms = wp_get_post_terms( $post->ID, 'category', array( 'fields' => 'ids' ) );

	// Bail if the term empty.
	if ( empty( $terms ) ) {
		return;
	}

	// Posts query arguments.
	$query = array(
		'post__not_in' => array( $post->ID ),
		'tax_query'    => array(
			array(
				'taxonomy' => 'category',
				'field'    => 'id',
				'terms'    => $terms,
				'operator' => 'IN'
			)
		),
		'posts_per_page' => 3,
		'post_type'      => 'post',
	);

	// Allow dev to filter the query.
	$args = apply_filters( 'leda_related_posts_args', $query );

	// The post query
	$related = new WP_Query( $args );

	if ( $related->have_posts() ) : ?>

		<div class="related-posts">
			<h3><?php _e( 'You might also like &hellip;', 'leda' ); ?></h3>
			<ul>
				<?php while ( $related->have_posts() ) : $related->the_post(); ?>
					<li>
						<?php if ( has_post_thumbnail() && $img ) : ?>
							<a class="thumbnail-link" href="<?php the_permalink(); ?>"><?php the_post_thumbnail( 'medium', array( 'class' => 'related-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?></a>
						<?php endif; ?>
						<?php the_title( sprintf( '<h2 class="entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>
						<time class="published" datetime="<?php echo esc_html( get_the_date( 'c' ) ); ?>"><?php echo esc_html( get_the_date() ); ?></time>
					</li>
				<?php endwhile; ?>
			</ul>
		</div>

	<?php endif;

	// Restore original Post Data.
	wp_reset_postdata();

}
endif;

if ( ! function_exists( 'leda_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 * @since  1.0.0
 */
function leda_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
		// Display trackbacks differently than normal comments.
	?>
	<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>" <?php hybrid_attr( 'comment' ); ?>>
		<article id="comment-<?php comment_ID(); ?>" class="comment-container">
			<p <?php hybrid_attr( 'comment-content' ); ?>><?php _e( 'Pingback:', 'leda' ); ?> <span <?php hybrid_attr( 'comment-author' ); ?>><span itemprop="name"><?php comment_author_link(); ?></span></span> <?php edit_comment_link( __( '(Edit)', 'leda' ), '<span class="edit-link">', '</span>' ); ?></p>
		</article>
	<?php
			break;
		default :
		// Proceed with normal comments.
		global $post;
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>" <?php hybrid_attr( 'comment' ); ?>>
		<article id="comment-<?php comment_ID(); ?>" class="comment-container">

			<div class="comment-avatar">
				<?php echo get_avatar( $comment, apply_filters( 'leda_comment_avatar_size', 80 ) ); ?>
				<span class="name" <?php hybrid_attr( 'comment-author' ); ?>><span itemprop="name"><?php echo get_comment_author_link(); ?></span></span>
				<?php echo leda_comment_author_badge(); ?>
			</div>

			<div class="comment-body">
				<div class="comment-wrapper">

					<div class="comment-head">
						<?php
							printf( '<span class="date"><a href="%1$s" ' . hybrid_get_attr( 'comment-permalink' ) . '><time datetime="%2$s" ' . hybrid_get_attr( 'comment-published' ) . '>%3$s</time></a> %4$s</span>',
								esc_url( get_comment_link( $comment->comment_ID ) ),
								get_comment_time( 'c' ),
								/* translators: 1: date, 2: time */
								sprintf( __( '%1$s at %2$s', 'leda' ), get_comment_date(), get_comment_time() ),
								sprintf( __( '%1$s&middot; Edit%2$s', 'leda' ), '<a href="' . get_edit_comment_link() . '" title="' . esc_attr__( 'Edit Comment', 'leda' ) . '">', '</a>' )
							);
						?>
					</div><!-- comment-head -->

					<div class="comment-content comment-entry" <?php hybrid_attr( 'comment-content' ); ?>>
						<?php if ( '0' == $comment->comment_approved ) : ?>
							<p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'leda' ); ?></p>
						<?php endif; ?>
						<?php comment_text(); ?>
						<span class="reply">
							<?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( '<i class="fa fa-reply"></i> Reply', 'leda' ), 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
						</span><!-- .reply -->
					</div><!-- .comment-content -->

				</div>
			</div>

		</article><!-- #comment-## -->
	<?php
		break;
	endswitch; // end comment_type check
}
endif;

if ( ! function_exists( 'leda_comment_author_badge' ) ) :
/**
 * Custom badge for post author comment
 *
 * @since  1.0.0
 */
function leda_comment_author_badge() {

	// Set up empty variable
	$output = '';

	// Get comment classes
	$classes = get_comment_class();

	if ( in_array( 'bypostauthor', $classes ) ) {
		$output = '<span class="author-badge">' . __( 'Author', 'leda' ) . '</span>';
	}

	// Display the badge
	return apply_filters( 'leda_comment_author_badge', $output );
}
endif;

if ( ! function_exists( 'leda_social_links' ) ) :
/**
 * Social profile links
 *
 * @since  1.0.0
 */
function leda_social_links() {

	// Get the data set in customizer
	$twitter   = get_theme_mod( 'leda-twitter' );
	$facebook  = get_theme_mod( 'leda-facebook' );
	$gplus     = get_theme_mod( 'leda-gplus' );
	$linkedin  = get_theme_mod( 'leda-linkedin' );
	$dribbble  = get_theme_mod( 'leda-dribbble' );
	$instagram = get_theme_mod( 'leda-instagram' );

	// Display the data
	echo '<div class="social-links">';
		if ( $twitter ) {
			echo '<a href="' . esc_url( $twitter ) . '"><i class="fa fa-twitter"></i></a>';
		}
		if ( $facebook ) {
			echo '<a href="' . esc_url( $facebook ) . '"><i class="fa fa-facebook"></i></a>';
		}
		if ( $gplus ) {
			echo '<a href="' . esc_url( $gplus ) . '"><i class="fa fa-google-plus"></i></a>';
		}
		if ( $linkedin ) {
			echo '<a href="' . esc_url( $linkedin ) . '"><i class="fa fa-linkedin"></i></a>';
		}
		if ( $dribbble ) {
			echo '<a href="' . esc_url( $dribbble ) . '"><i class="fa fa-dribbble"></i></a>';
		}
		if ( $instagram ) {
			echo '<a href="' . esc_url( $instagram ) . '"><i class="fa fa-instagram"></i></a>';
		}
	echo '</div>';

}
endif;

if ( ! function_exists( 'leda_footer_text' ) ) :
/**
 * Footer Text
 */
function leda_footer_text() {

	// Get the customizer data
	$default = '&copy; Copyright ' . date( 'Y' ) . ' <a href="' . esc_url( home_url() ) . '">' . esc_attr( get_bloginfo( 'name' ) ) . '</a> &middot; Designed by <a href="http://www.theme-junkie.com/">Theme Junkie</a>';
	$footer_text = get_theme_mod( 'leda-footer-text', $default );

	// Display the data
	echo '<p class="copyright">' . wp_kses_post( $footer_text ) . '</p>';

}
endif;

if ( ! function_exists( 'leda_posts_query_404' ) ) :
/**
 * Custom query to display latest posts on 404 page.
 *
 * @since  1.0.0
 */
function leda_posts_query_404() {

	// Posts arguments
	$args = array(
		'post_type'      => 'post',
		'posts_per_page' => 6
	);

	// Allow dev to filter the arguments
	$posts = apply_filters( 'leda_posts_query_404_args', $args );

	// Our hero!
	$posts = new WP_Query( $args );

	// Display the posts
	if ( $posts->have_posts() ) :
		while ( $posts->have_posts() ) : $posts->the_post();
			get_template_part( 'content', get_post_format() );
		endwhile;
	endif;

	// Reset the query.
	wp_reset_postdata();

}
endif;
